#
# spec file for package xfce4-screenshooter
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin screenshooter
%bcond_with git

Name:           xfce4-screenshooter
Version:        1.9.9
Release:        bp153.2.3.1
Summary:        Screenshot Tool for the Xfce Desktop
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://goodies.xfce.org/projects/applications/xfce4-screenshooter
Source:         https://archive.xfce.org/src/apps/xfce4-screenshooter/1.9/%{name}-%{version}.tar.bz2
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(exo-2) >= 0.11.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.10.0
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Recommends:     %{name}-lang = %{version}
# needs xfhelp4
Requires:       libxfce4ui-tools
Suggests:       xfce4-%{plugin}-plugin
Obsoletes:      xfce4-screenshooter-doc <= 1.8.1
Provides:       xfce4-screenshooter-doc = %{version}

%description
Xfce4 Screenshooter is a tool for taking screenshots, it can capture the entire
screen, the active window or a selected region. Screenshots may be taken with a
user-specified delay and the resulting images can be saved to a PNG file,
copied it to the clipboard, opened with another application, or uploaded to
ZimageZ, a free online image hosting service.

%package -n xfce4-%{plugin}-plugin
Summary:        Screenshot Plugin for the Xfce Panel
Group:          System/GUI/XFCE
Requires:       xfce4-panel >= %{panel_version}
Requires:       xfce4-screenshooter = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description -n xfce4-%{plugin}-plugin
This package contains the xfce4-screenshooter Xfce panel plugin.

%lang_package

%prep
%setup -q

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libscreenshooterplugin.la

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%find_lang xfce4-screenshooter %{?no_lang_C}

%suse_update_desktop_file -r xfce4-screenshooter -G 'Screenshot Tool' Utility X-SuSE-DesktopUtility GTK

%fdupes %{buildroot}%{_datadir}

%files
%doc NEWS README.md TODO
%license COPYING
%{_bindir}/xfce4-screenshooter
%{_datadir}/icons/hicolor/*
%{_datadir}/applications/xfce4-screenshooter.desktop
%{_datadir}/metainfo/xfce4-screenshooter.appdata.xml
%{_mandir}/man1/xfce4-screenshooter.1*

%files -n xfce4-%{plugin}-plugin
%{_libdir}/xfce4/panel/plugins/libscreenshooterplugin.so
%{_datadir}/xfce4/panel/plugins/screenshooter.desktop

%files lang -f %{name}.lang

%changelog
* Thu May 20 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.9
  * Add link to Imgur ToS (gxo#apps/xfce4-screenshooter#54)
  * Add notice about imgur (gxo#apps/xfce4-screenshooter#53)
  * Add launchable tag to appdata.xml
  * Update help message for --save option
  * Add combobox with file extensions
    (gxo#apps/xfce4-screenshooter#6)
  * Add option to capture window border or not
    (gxo#apps/xfce4-screenshooter#4)
  * Preserve last used extension
  * Save screenshots according to the extension
    (gxo#apps/xfce4-screenshooter#6)
  * Avoid save dialog loop if action was specified from CLI
    (gxo#apps/xfce4-screenshooter#41)
  * Respect windows scaling (gxo#apps/xfce4-screenshoote!18)
  * Fix compilation warnings
  * Add version check for pango
  * Correctly calculate dimensions of size window
    (gxo#apps/xfce4-screenshooter#37)
  * Add option to disable Imgur upload
    (gxo#apps/xfce4-screenshooter#20)
  * Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.9.8
  - Fix dialog icons and add title to error dialog
  - Go back to actions dialog if image upload fails (#12)
  - Go back to actions dialog if GtkFileChooser is dismissed (#33)
  - Make radio buttons execute actions on enter/space press
  - Exclude shadow borders from CSD windows (!10)
  - Capture mouse cursor in rectangle selection (#30)
  - Region size should show updated size (!9)
  - Add info about Ctrl to "Select region" tooltip
  - Replace AC_CONFIG_MACRO_DIR with AC_CONFIG_MACRO_DIRS (!4)
  - Added 24px and 32px icons
  - Fix screenshot capture when scale > 1
  - Add new App icon and switch to rDNS icon name
  - Switch to README.md and foreign automake mode
  - bxo#16717: Move from exo-csource to xdt-csource
  - Update homepage link at appdata.xml
  - Translation Updates
* Mon Nov  4 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.7
  * Add warning notice to imgur upload option (bxo#15347)
  * Fix cursor capture when near screen edge (bxo#9262)
  * Improve wording (bxo#15429)
  * Allow compilation with panel 4.15
  * Restore libxfce4ui 4.12 compatibility
  * Translation Updates
* Mon Aug 26 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.6
  * Do not show translation info on --help output (bxo#15883)
  * Avoid destroying size window twice (bxo#15792)
  * Replace GtkStock buttons
  * Add missing NULL as last parameter of
    xfce_titled_dialog_new_with_buttons() (bxo#14973)
  * Do not use root coordinates for region capture (bxo#15406)
  * Install AppData into metainfo
  * Update AppData file
  * Try to grab seat more than once (bxo#15320)
  * Use new xfce_gdk_screen_get_geometry if available
  * Make screenshooter-imgur-dialog.ui translatable (bxo#15254)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Thu Aug 15 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Renamed Panel Plugin subpackage to follow upstream naming
  xfce4-foo-plugin
- Added bcond for git master builds
* Sat Mar 30 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 1.9.5
  * Bug fixed:
  - Panel plugin: allow it to save files (bxo#15187)
* Tue Mar 19 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Switched URL and Source to https:// in the spec file.
* Mon Mar 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.9.4
  * Enhancements:
  - Extended save function to also take files (bxo#14156)
  - Show width and height of selection area (bxo#12664)
  - Improved imgur dialog (bxo#14973)
  - Don't save region/delay/show_mouse if region was specified from CLI
  * Bugs fixed:
  - React to core X input events when XInput is not available (bxo#15166)
  - Fix crash and properly handle cursors on HiDPI
  - Delay in panel plugin does not work (bxo#14604)
- Dropped obsolete macros
* Sun Aug 12 2018 seife+obs@b1-systems.com
- update to version 1.9.3
  - Allow user to move selection rectangle (bxo#14365)
  - Allow and remember 0sec delay for all regions (bxo#13763)
  - Fix clipboard action handling (bxo#14513)
* Tue May 15 2018 seife+obs@b1-systems.com
- update to version 1.9.2
  - Remove zimagez support (bxo#14283)
  - Use g_app_info_launch() for command launching (bxo#13886)
  - Dismiss the progress dialog after upload (bxo#12519)
  - Improve thumbnail size clamping
  - Allow --clipboard option to be used with the others (bxo#14120)
  - Handle device grab failure (bxo#10259)
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to version 1.9.1
  - Fix crash on program exit after image upload (bxo#13415)
- version 1.9.0
  - Use HTTPS for imgur (bxo#13415)
- version 1.8.99
  - Port to GTK+3
  - Fix appdata description
  - Fix crash in GValueArray handling (bxo#11879)
  - Use while instead of when in strings (bxo#12157)
  - Fix gray overlay in region mode screenshots (bxo#11922)
  - Fix crash when uploading to zimagez (bxo#11879)
- Updated translations
* Tue Jan 27 2015 gber@opensuse.org
- update to version 1.8.2
  - Enhancements:
  - Add imgur.com as possible upload option (bxo#6899)
  - Add appdate file (bxo#11202)
  - Make region selection with compositing on more usable on
    darker backgrounds (bxo#9592)
  - Updated translations
  - Bugs fixed:
  - Fix keyboard navigation between choices (bxo#11325)
  - Fix build with automake 1.13 (bxo#10030)
  - Use filename-friendly date format for saved files (bxo#8445)
  - drop obsolete xfce4-screenshooter-fix-plugin-linking.patch
    xfce4-screenshooter-use-docdir.patch,
    xfce4-screenshooter-automake-1.13.patch,
    xfce4-screenshooter-automake-1.14.patch
  - drop -doc subpackage, documentation has been removed
* Thu Oct 16 2014 dimstar@opensuse.org
- Add xfce4-screenshooter-automake-1.14.patch: Fully intialize
  before doing furher actions. Works around an issue with AM 1.14.
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Mon May  7 2012 gber@opensuse.org
- fix xfce4-screenshooter-fix-plugin-linking.patch so the panel
  plugin is linked against libscreenshooter
- fix help function by depending on libxfce4ui-tools which provides
  xfhelp4 again
* Thu May  3 2012 gber@opensuse.org
- update to version 1.8.1
  - adapting the panel plugin to xfce4-panel 4.9+
  - add a clipboard CLI option
  - panel plugin is now built as a library
  - fix crash with some window managers
  - fix crash with NULL save path
  - install documentation to new location
  - add explicit -lm link to LIBADD
  - plugin installation location compatible with xfce4-panel 4.9+
  - update outdated man page
- rebased xfce4-screenshooter-1.8.0-use-docdir.patch as
  xfce4-screenshooter-use-docdir.patch
- added xfce4-screenshooter-fix-plugin-linking.patch in order to
  link the plugin module correctly
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- added xfce4-screenshooter-fix-crash-with-some-wms.patch which
  fixes a crash when taking a screenshot of a window with some
  window managers (bxo#8080)
- correct dependencies
* Wed Mar 14 2012 gber@opensuse.org
- recommend -lang subpackage
* Fri Oct 21 2011 gber@opensuse.org
- added xfce4-screenshooter-1.8.0-use-docdir.patch in order to
  allow installation of documentation under docdir
- install HTML documentation under
  /usr/share/xfce4/xfce4-screenshooter/html
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Mon Sep 19 2011 gber@opensuse.org
- added xfce4-screenshooter-fix-libm-underlinking.patch in order to
  explicitly link against libm
* Mon Aug  1 2011 gber@opensuse.org
- update to version 1.8.0
  - capture the cursor using XFIXES
  - generate valid BBCode
  - further bugfixes and translation updates
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb  3 2011 gber@opensuse.org
- build documentation
* Thu Feb  3 2011 gber@opensuse.org
- update to current git snapshot (1.7.9.99_git20110203)
  - port to current exo
  - port from libxfcegui4 to libxfce4ui
  - many bugfixes
  - translation updates
- dropped obsolete xfce4-screenshooter-1.7.9-fix-crash.patch and
  xfce4-screenshooter-1.7.9-use-system-exo.patch
* Mon Dec 27 2010 gber@opensuse.org
- correct group and URL
* Sun Dec  5 2010 gber@opensuse.org
- Initial packaging
